# This script file presents the use of some of the most
# fundamental Python idioms.

# Import all necessary Python frameworks.
import random
from functools import partial
# ===================================================================================
# Call a function until a sentiment value.
# ===================================================================================

# Traditional approach.
# Set the maximum random integer that can be sampled.
max_value = 100
# Set the sentinel value which designate the stopping
# criterion for the sampling process.
sentinel_value = 0
# Initialize a list for storing all values that have been
# sampled until the generation of the sentinel value.
R = []
# Simulate the sampling process.
while True:
	random_value = random.randint(0,max_value)
	if random_value == 0:
		break
	R.append(random_value)
print("===========================================================================")
print("{} samples had to be drawn before generating the sentinel value".format(len(R)))	
print(R)

# Pythonic approach.
R = []
for random_value in iter(partial(random.randint,0,max_value), sentinel_value):
	R.append(random_value)
print("===========================================================================")
print("{} samples had to be drawn before generating the sentinel value".format(len(R)))	
print(R)